package j2d.gui;

import gui.run.RunMenu;
import gui.run.RunMenuItem;
import j2d.ShortImageBean;
import j2d.color.ColorizerPanel;
import j2d.hpp.*;

import javax.swing.*;
import java.awt.*;

/**
 * Created by IntelliJ IDEA.
 * User: dlyon
 * Date: Feb 24, 2005
 * Time: 2:34:13 PM
 * Copyright DocJava, 2005
 */
public class MainMenus {
    public static void addFileMenu(final Main main, JMenuBar mb) {
        RunMenu fileMenu = new RunMenu("[File");
        mb.add(fileMenu);

        fileMenu.add(new RunMenuItem("[Open{ctrl O}",
                Hex.getOpenIcon()) {
            public void run() {
                main.openImage();
            }
        });

        fileMenu.add(new RunMenuItem("[Capture screen{alt 4}",
                Hex.getCaptureIcon()) {
            public void run() {
                main.captureScreen();
            }
        });
        fileMenu.add(new RunMenuItem("C[apture camera{alt C}",
                Hex.getCaptureIcon()) {
            public void run() {
                main.captureVideo();
            }
        });
        fileMenu.add(new RunMenuItem("[Revert{ctrl W}",
                Hex.getRevertIcon()) {
            public void run() {
                main.revertImage();
            }
        });
        fileMenu.add(new RunMenuItem("[Save{ctrl S}",
                Hex.getSaveIcon()) {
            public void run() {
                main.saveImage();
            }
        });
        fileMenu.add(new RunMenuItem("[Print Hex{ctrl h}") {
            public void run() {
                main.printHexImage();
            }
        });

        fileMenu.add(new RunMenuItem("E[xit{ctrl Q}",
                Hex.getExitIcon()) {
            public void run() {
                main.shutdown();
            }
        });
    }

    public static RunMenu getHistogramMenu(final Main main) {
        RunMenu processMenu = new RunMenu("[Histogram");
        processMenu.add(new RunMenuItem("H[istogram Panel{ctrl i}") {
            public void run() {
                HistogramPanel cp = new HistogramPanel(main);
                main.addPanel(cp, getText());
            }
        });
        processMenu.add(new RunMenuItem("[Exponential Stretch") {
            public void run() {
                if (main.estStretchControls == null ||
                        main.estStretchControls.isClosed()) {
                    main.launchStretchControls();
                }
            }
        });
        processMenu.add(new RunMenuItem("[ContrastPanel{alt ctrl C}") {
            public void run() {
                ContrastPanel cp = new ContrastPanel(main);
                main.addPanel(cp, getText());
            }
        });

        return processMenu;
    }

    public static void addProcessMenu(final Main main, JMenuBar mb) {
        RunMenu processMenu = new RunMenu("[process");
        processMenu.add(getHistogramMenu(main));
        mb.add(processMenu);

        processMenu.add(new RunMenuItem("GreyHppFilter3Panel") {
            public void run() {
                main.addPanel(new GreyHppFilter3Panel(main), getText());
            }
        });
        processMenu.add(new RunMenuItem("Pse[udoColorFilter") {
            public void run() {
                main.addPanel(new ColorizerPanel(main), getText());
            }
        });
        processMenu.add(new RunMenuItem("ThresholdFilter3Panel") {
            public void run() {
                main.addPanel(new ThresholdFilter3Panel(main), getText());
            }
        });
        processMenu.add(new RunMenuItem("ThresholdPanel") {
            public void run() {
                main.addPanel(new ThresholdPanel(main), getText());
            }
        });
        //
        processMenu.add(new RunMenuItem("[negate{ctrl C}") {
            public void run() {
                main.process(new InvertFilter());
            }
        });
        processMenu.add(new RunMenuItem("salt and pepper 1000") {
            public void run() {
                Image img = main.getImage();
                ShortImageBean sib = new ShortImageBean(img);
                sib.saltAndPepper(1000);
                main.setImage(sib.getImage());
            }
        });
        processMenu.add(new RunMenuItem("gray") {
            public void run() {
                Image img = main.getImage();
                ShortImageBean sib = new ShortImageBean(img);
                sib.gray();
                main.setImage(sib.getImage());
            }
        });
    }
}
